Crabsnack
---------

Can serve as a boilerplate for any sea food related web application.

Going easy on abstraction wrappers both on the backend and frontend sides.

Frontend - no MVC framework however fancy it appears to be.

Backend - an ORM wrapper is out.
